#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiCalendarRecurrencePatternDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.mapi_calendar_exception_info_dto import MapiCalendarExceptionInfoDto


class MapiCalendarRecurrencePatternDto(object):
    """Mapi recurrence pattern.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'calendar_type': 'str',
        'deleted_instance_dates': 'list[datetime]',
        'end_date': 'datetime',
        'end_type': 'str',
        'exceptions': 'list[MapiCalendarExceptionInfoDto]',
        'frequency': 'str',
        'modified_instance_dates': 'list[datetime]',
        'occurrence_count': 'int',
        'pattern_type': 'str',
        'period': 'int',
        'sliding_flag': 'bool',
        'start_date': 'datetime',
        'week_start_day': 'str',
        'discriminator': 'str'
    }

    attribute_map = {
        'calendar_type': 'calendarType',
        'deleted_instance_dates': 'deletedInstanceDates',
        'end_date': 'endDate',
        'end_type': 'endType',
        'exceptions': 'exceptions',
        'frequency': 'frequency',
        'modified_instance_dates': 'modifiedInstanceDates',
        'occurrence_count': 'occurrenceCount',
        'pattern_type': 'patternType',
        'period': 'period',
        'sliding_flag': 'slidingFlag',
        'start_date': 'startDate',
        'week_start_day': 'weekStartDay',
        'discriminator': 'discriminator'
    }

    def __init__(self, calendar_type: str = None, deleted_instance_dates: List[datetime] = None, end_date: datetime = None, end_type: str = None, exceptions: List[MapiCalendarExceptionInfoDto] = None, frequency: str = None, modified_instance_dates: List[datetime] = None, occurrence_count: int = None, pattern_type: str = None, period: int = None, sliding_flag: bool = None, start_date: datetime = None, week_start_day: str = None):
        """
        Mapi recurrence pattern.             
        :param calendar_type: Enumerated the calendar type of the mapi recurrence Enum, available values: Default, CalGregorian, CalGregorianUs, CalJapan, CalTaiwan, CalKorea, CalHijri, CalThai, CalHebrew, CalGregorianMeFrench, CalGregorianArabic, CalGregorianXLitEnglish, CalGregorianXLitFrench, CalLunarJapanese, CalChineseLunar, CalSaka, CalLunarEtoChn, CalLunarEtoKor, CalLunarRokuyou, CalLunarKorean, CalUmAlQura
        :type calendar_type: str
        :param deleted_instance_dates: An array of dates, each of which is the original instance date of either a deleted instance or a modified instance for this recurrence.             
        :type deleted_instance_dates: List[datetime]
        :param end_date: End date of an item recurrence pattern.             
        :type end_date: datetime
        :param end_type: Enumerates the ending type for the recurrence. Enum, available values: None, EndAfterDate, EndAfterNOccurrences, NeverEnd
        :type end_type: str
        :param exceptions: An exception specifies changes to an instance of a recurring series.             
        :type exceptions: List[MapiCalendarExceptionInfoDto]
        :param frequency: Enumerates mapi calendar recurrence frequency Enum, available values: None, Daily, Weekly, Monthly, Yearly
        :type frequency: str
        :param modified_instance_dates: An array of dates, each of which is the date of a modified instance.             
        :type modified_instance_dates: List[datetime]
        :param occurrence_count: Number of occurrences in a recurrence.             
        :type occurrence_count: int
        :param pattern_type: Enumerates the mapi calendar recurrence pattern types Enum, available values: Day, Week, Month, MonthEnd, MonthNth, HjMonth, HjMonthNth, HjMonthEnd
        :type pattern_type: str
        :param period: Interval at which the meeting pattern repeats.             
        :type period: int
        :param sliding_flag: Defines whether pattern is sliding or not.             
        :type sliding_flag: bool
        :param start_date: Start date of an item recurrence pattern.             
        :type start_date: datetime
        :param week_start_day: Day of week. Enum, available values: Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday
        :type week_start_day: str
        """

        self._calendar_type = None
        self._deleted_instance_dates = None
        self._end_date = None
        self._end_type = None
        self._exceptions = None
        self._frequency = None
        self._modified_instance_dates = None
        self._occurrence_count = None
        self._pattern_type = None
        self._period = None
        self._sliding_flag = None
        self._start_date = None
        self._week_start_day = None

        if calendar_type is not None:
            self.calendar_type = calendar_type
        if deleted_instance_dates is not None:
            self.deleted_instance_dates = deleted_instance_dates
        if end_date is not None:
            self.end_date = end_date
        if end_type is not None:
            self.end_type = end_type
        if exceptions is not None:
            self.exceptions = exceptions
        if frequency is not None:
            self.frequency = frequency
        if modified_instance_dates is not None:
            self.modified_instance_dates = modified_instance_dates
        if occurrence_count is not None:
            self.occurrence_count = occurrence_count
        if pattern_type is not None:
            self.pattern_type = pattern_type
        if period is not None:
            self.period = period
        if sliding_flag is not None:
            self.sliding_flag = sliding_flag
        if start_date is not None:
            self.start_date = start_date
        if week_start_day is not None:
            self.week_start_day = week_start_day


    @property
    def calendar_type(self) -> str:
        """
        Enumerated the calendar type of the mapi recurrence Enum, available values: Default, CalGregorian, CalGregorianUs, CalJapan, CalTaiwan, CalKorea, CalHijri, CalThai, CalHebrew, CalGregorianMeFrench, CalGregorianArabic, CalGregorianXLitEnglish, CalGregorianXLitFrench, CalLunarJapanese, CalChineseLunar, CalSaka, CalLunarEtoChn, CalLunarEtoKor, CalLunarRokuyou, CalLunarKorean, CalUmAlQura

        :return: The calendar_type of this MapiCalendarRecurrencePatternDto.
        :rtype: str
        """
        return self._calendar_type

    @calendar_type.setter
    def calendar_type(self, calendar_type: str):
        """
        Enumerated the calendar type of the mapi recurrence Enum, available values: Default, CalGregorian, CalGregorianUs, CalJapan, CalTaiwan, CalKorea, CalHijri, CalThai, CalHebrew, CalGregorianMeFrench, CalGregorianArabic, CalGregorianXLitEnglish, CalGregorianXLitFrench, CalLunarJapanese, CalChineseLunar, CalSaka, CalLunarEtoChn, CalLunarEtoKor, CalLunarRokuyou, CalLunarKorean, CalUmAlQura

        :param calendar_type: The calendar_type of this MapiCalendarRecurrencePatternDto.
        :type: str
        """
        if calendar_type is None:
            raise ValueError("Invalid value for `calendar_type`, must not be `None`")
        self._calendar_type = calendar_type

    @property
    def deleted_instance_dates(self) -> List[datetime]:
        """
        An array of dates, each of which is the original instance date of either a deleted instance or a modified instance for this recurrence.             

        :return: The deleted_instance_dates of this MapiCalendarRecurrencePatternDto.
        :rtype: list[datetime]
        """
        return self._deleted_instance_dates

    @deleted_instance_dates.setter
    def deleted_instance_dates(self, deleted_instance_dates: List[datetime]):
        """
        An array of dates, each of which is the original instance date of either a deleted instance or a modified instance for this recurrence.             

        :param deleted_instance_dates: The deleted_instance_dates of this MapiCalendarRecurrencePatternDto.
        :type: list[datetime]
        """
        self._deleted_instance_dates = deleted_instance_dates

    @property
    def end_date(self) -> datetime:
        """
        End date of an item recurrence pattern.             

        :return: The end_date of this MapiCalendarRecurrencePatternDto.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date: datetime):
        """
        End date of an item recurrence pattern.             

        :param end_date: The end_date of this MapiCalendarRecurrencePatternDto.
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")
        self._end_date = end_date

    @property
    def end_type(self) -> str:
        """
        Enumerates the ending type for the recurrence. Enum, available values: None, EndAfterDate, EndAfterNOccurrences, NeverEnd

        :return: The end_type of this MapiCalendarRecurrencePatternDto.
        :rtype: str
        """
        return self._end_type

    @end_type.setter
    def end_type(self, end_type: str):
        """
        Enumerates the ending type for the recurrence. Enum, available values: None, EndAfterDate, EndAfterNOccurrences, NeverEnd

        :param end_type: The end_type of this MapiCalendarRecurrencePatternDto.
        :type: str
        """
        if end_type is None:
            raise ValueError("Invalid value for `end_type`, must not be `None`")
        self._end_type = end_type

    @property
    def exceptions(self) -> List[MapiCalendarExceptionInfoDto]:
        """
        An exception specifies changes to an instance of a recurring series.             

        :return: The exceptions of this MapiCalendarRecurrencePatternDto.
        :rtype: list[MapiCalendarExceptionInfoDto]
        """
        return self._exceptions

    @exceptions.setter
    def exceptions(self, exceptions: List[MapiCalendarExceptionInfoDto]):
        """
        An exception specifies changes to an instance of a recurring series.             

        :param exceptions: The exceptions of this MapiCalendarRecurrencePatternDto.
        :type: list[MapiCalendarExceptionInfoDto]
        """
        self._exceptions = exceptions

    @property
    def frequency(self) -> str:
        """
        Enumerates mapi calendar recurrence frequency Enum, available values: None, Daily, Weekly, Monthly, Yearly

        :return: The frequency of this MapiCalendarRecurrencePatternDto.
        :rtype: str
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency: str):
        """
        Enumerates mapi calendar recurrence frequency Enum, available values: None, Daily, Weekly, Monthly, Yearly

        :param frequency: The frequency of this MapiCalendarRecurrencePatternDto.
        :type: str
        """
        if frequency is None:
            raise ValueError("Invalid value for `frequency`, must not be `None`")
        self._frequency = frequency

    @property
    def modified_instance_dates(self) -> List[datetime]:
        """
        An array of dates, each of which is the date of a modified instance.             

        :return: The modified_instance_dates of this MapiCalendarRecurrencePatternDto.
        :rtype: list[datetime]
        """
        return self._modified_instance_dates

    @modified_instance_dates.setter
    def modified_instance_dates(self, modified_instance_dates: List[datetime]):
        """
        An array of dates, each of which is the date of a modified instance.             

        :param modified_instance_dates: The modified_instance_dates of this MapiCalendarRecurrencePatternDto.
        :type: list[datetime]
        """
        self._modified_instance_dates = modified_instance_dates

    @property
    def occurrence_count(self) -> int:
        """
        Number of occurrences in a recurrence.             

        :return: The occurrence_count of this MapiCalendarRecurrencePatternDto.
        :rtype: int
        """
        return self._occurrence_count

    @occurrence_count.setter
    def occurrence_count(self, occurrence_count: int):
        """
        Number of occurrences in a recurrence.             

        :param occurrence_count: The occurrence_count of this MapiCalendarRecurrencePatternDto.
        :type: int
        """
        if occurrence_count is None:
            raise ValueError("Invalid value for `occurrence_count`, must not be `None`")
        self._occurrence_count = occurrence_count

    @property
    def pattern_type(self) -> str:
        """
        Enumerates the mapi calendar recurrence pattern types Enum, available values: Day, Week, Month, MonthEnd, MonthNth, HjMonth, HjMonthNth, HjMonthEnd

        :return: The pattern_type of this MapiCalendarRecurrencePatternDto.
        :rtype: str
        """
        return self._pattern_type

    @pattern_type.setter
    def pattern_type(self, pattern_type: str):
        """
        Enumerates the mapi calendar recurrence pattern types Enum, available values: Day, Week, Month, MonthEnd, MonthNth, HjMonth, HjMonthNth, HjMonthEnd

        :param pattern_type: The pattern_type of this MapiCalendarRecurrencePatternDto.
        :type: str
        """
        if pattern_type is None:
            raise ValueError("Invalid value for `pattern_type`, must not be `None`")
        self._pattern_type = pattern_type

    @property
    def period(self) -> int:
        """
        Interval at which the meeting pattern repeats.             

        :return: The period of this MapiCalendarRecurrencePatternDto.
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period: int):
        """
        Interval at which the meeting pattern repeats.             

        :param period: The period of this MapiCalendarRecurrencePatternDto.
        :type: int
        """
        if period is None:
            raise ValueError("Invalid value for `period`, must not be `None`")
        self._period = period

    @property
    def sliding_flag(self) -> bool:
        """
        Defines whether pattern is sliding or not.             

        :return: The sliding_flag of this MapiCalendarRecurrencePatternDto.
        :rtype: bool
        """
        return self._sliding_flag

    @sliding_flag.setter
    def sliding_flag(self, sliding_flag: bool):
        """
        Defines whether pattern is sliding or not.             

        :param sliding_flag: The sliding_flag of this MapiCalendarRecurrencePatternDto.
        :type: bool
        """
        if sliding_flag is None:
            raise ValueError("Invalid value for `sliding_flag`, must not be `None`")
        self._sliding_flag = sliding_flag

    @property
    def start_date(self) -> datetime:
        """
        Start date of an item recurrence pattern.             

        :return: The start_date of this MapiCalendarRecurrencePatternDto.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date: datetime):
        """
        Start date of an item recurrence pattern.             

        :param start_date: The start_date of this MapiCalendarRecurrencePatternDto.
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")
        self._start_date = start_date

    @property
    def week_start_day(self) -> str:
        """
        Day of week. Enum, available values: Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday

        :return: The week_start_day of this MapiCalendarRecurrencePatternDto.
        :rtype: str
        """
        return self._week_start_day

    @week_start_day.setter
    def week_start_day(self, week_start_day: str):
        """
        Day of week. Enum, available values: Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday

        :param week_start_day: The week_start_day of this MapiCalendarRecurrencePatternDto.
        :type: str
        """
        if week_start_day is None:
            raise ValueError("Invalid value for `week_start_day`, must not be `None`")
        self._week_start_day = week_start_day

    @property
    def discriminator(self) -> str:
        """
        Gets the discriminator of this MapiCalendarRecurrencePatternDto.

        :return: The discriminator of this MapiCalendarRecurrencePatternDto.
        :rtype: str
        """
        return self.__class__.__name__

    @discriminator.setter
    def discriminator(self, discriminator: str):
        """
        Sets the discriminator of this MapiCalendarRecurrencePatternDto.

        :param discriminator: The discriminator of this MapiCalendarRecurrencePatternDto.
        :type: str
        """
        pass    # setter is ignored for discriminator property

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiCalendarRecurrencePatternDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiContactDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.mapi_attachment_dto import MapiAttachmentDto
from AsposeEmailCloudSdk.models.mapi_contact_electronic_address_property_set_dto import MapiContactElectronicAddressPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_event_property_set_dto import MapiContactEventPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_name_property_set_dto import MapiContactNamePropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_other_property_set_dto import MapiContactOtherPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_personal_info_property_set_dto import MapiContactPersonalInfoPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_photo_dto import MapiContactPhotoDto
from AsposeEmailCloudSdk.models.mapi_contact_physical_address_property_set_dto import MapiContactPhysicalAddressPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_professional_property_set_dto import MapiContactProfessionalPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_telephone_property_set_dto import MapiContactTelephonePropertySetDto
from AsposeEmailCloudSdk.models.mapi_message_item_base_dto import MapiMessageItemBaseDto
from AsposeEmailCloudSdk.models.mapi_property_dto import MapiPropertyDto
from AsposeEmailCloudSdk.models.mapi_recipient_dto import MapiRecipientDto


class MapiContactDto(MapiMessageItemBaseDto):
    """Represents outlook contact information.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachments': 'list[MapiAttachmentDto]',
        'billing': 'str',
        'body': 'str',
        'body_html': 'str',
        'body_rtf': 'str',
        'body_type': 'str',
        'categories': 'list[str]',
        'companies': 'list[str]',
        'item_id': 'str',
        'message_class': 'str',
        'mileage': 'str',
        'recipients': 'list[MapiRecipientDto]',
        'sensitivity': 'str',
        'subject': 'str',
        'subject_prefix': 'str',
        'properties': 'list[MapiPropertyDto]',
        'discriminator': 'str',
        'electronic_addresses': 'MapiContactElectronicAddressPropertySetDto',
        'events': 'MapiContactEventPropertySetDto',
        'name_info': 'MapiContactNamePropertySetDto',
        'other_fields': 'MapiContactOtherPropertySetDto',
        'personal_info': 'MapiContactPersonalInfoPropertySetDto',
        'photo': 'MapiContactPhotoDto',
        'physical_addresses': 'MapiContactPhysicalAddressPropertySetDto',
        'professional_info': 'MapiContactProfessionalPropertySetDto',
        'telephones': 'MapiContactTelephonePropertySetDto'
    }

    attribute_map = {
        'attachments': 'attachments',
        'billing': 'billing',
        'body': 'body',
        'body_html': 'bodyHtml',
        'body_rtf': 'bodyRtf',
        'body_type': 'bodyType',
        'categories': 'categories',
        'companies': 'companies',
        'item_id': 'itemId',
        'message_class': 'messageClass',
        'mileage': 'mileage',
        'recipients': 'recipients',
        'sensitivity': 'sensitivity',
        'subject': 'subject',
        'subject_prefix': 'subjectPrefix',
        'properties': 'properties',
        'discriminator': 'discriminator',
        'electronic_addresses': 'electronicAddresses',
        'events': 'events',
        'name_info': 'nameInfo',
        'other_fields': 'otherFields',
        'personal_info': 'personalInfo',
        'photo': 'photo',
        'physical_addresses': 'physicalAddresses',
        'professional_info': 'professionalInfo',
        'telephones': 'telephones'
    }

    def __init__(self, attachments: List[MapiAttachmentDto] = None, billing: str = None, body: str = None, body_html: str = None, body_rtf: str = None, body_type: str = None, categories: List[str] = None, companies: List[str] = None, item_id: str = None, message_class: str = None, mileage: str = None, recipients: List[MapiRecipientDto] = None, sensitivity: str = None, subject: str = None, subject_prefix: str = None, properties: List[MapiPropertyDto] = None, electronic_addresses: MapiContactElectronicAddressPropertySetDto = None, events: MapiContactEventPropertySetDto = None, name_info: MapiContactNamePropertySetDto = None, other_fields: MapiContactOtherPropertySetDto = None, personal_info: MapiContactPersonalInfoPropertySetDto = None, photo: MapiContactPhotoDto = None, physical_addresses: MapiContactPhysicalAddressPropertySetDto = None, professional_info: MapiContactProfessionalPropertySetDto = None, telephones: MapiContactTelephonePropertySetDto = None):
        """
        Represents outlook contact information.             
        :param attachments: Message item attachments.             
        :type attachments: List[MapiAttachmentDto]
        :param billing: Billing information associated with an item.             
        :type billing: str
        :param body: Message text.             
        :type body: str
        :param body_html: Gets the BodyRtf of the message converted to HTML, if present, otherwise an empty string.             
        :type body_html: str
        :param body_rtf: RTF formatted message text.             
        :type body_rtf: str
        :param body_type: The content type of message body. Enum, available values: PlainText, Html, Rtf
        :type body_type: str
        :param categories: Contains keywords or categories for the message object.             
        :type categories: List[str]
        :param companies: Contains the names of the companies that are associated with an item.             
        :type companies: List[str]
        :param item_id: The item id, uses with a server.             
        :type item_id: str
        :param message_class: Case-sensitive string that identifies the sender-defined message class, such as IPM.Note. The message class specifies the type, purpose, or content of the message.             
        :type message_class: str
        :param mileage: Contains the mileage information that is associated with an item.             
        :type mileage: str
        :param recipients: Recipients of the message.             
        :type recipients: List[MapiRecipientDto]
        :param sensitivity: Contains values that indicate the message sensitivity. Enum, available values: None, Personal, Private, CompanyConfidential
        :type sensitivity: str
        :param subject: Subject of the message.             
        :type subject: str
        :param subject_prefix: Subject prefix that typically indicates some action on a message, such as \"FW: \" for forwarding.             
        :type subject_prefix: str
        :param properties: List of MAPI properties             
        :type properties: List[MapiPropertyDto]
        :param electronic_addresses: Specify properties for up to three different e-mail addresses and three different fax addresses.             
        :type electronic_addresses: MapiContactElectronicAddressPropertySetDto
        :param events: Specify events associated with a contact.             
        :type events: MapiContactEventPropertySetDto
        :param name_info: The properties are used to specify the name of the person represented by the contact.             
        :type name_info: MapiContactNamePropertySetDto
        :param other_fields: Specify other fields of contact.             
        :type other_fields: MapiContactOtherPropertySetDto
        :param personal_info: Specify other additional contact information.             
        :type personal_info: MapiContactPersonalInfoPropertySetDto
        :param photo: Contact photo.             
        :type photo: MapiContactPhotoDto
        :param physical_addresses: Specify three physical addresses: Home Address, Work Address, and Other Address. One of the addresses can be marked as the Mailing Address.             
        :type physical_addresses: MapiContactPhysicalAddressPropertySetDto
        :param professional_info: Properties are used to store professional details for the person represented by the contact.             
        :type professional_info: MapiContactProfessionalPropertySetDto
        :param telephones: Specify telephone numbers for the contact.             
        :type telephones: MapiContactTelephonePropertySetDto
        """
        super(MapiContactDto, self).__init__()

        self._electronic_addresses = None
        self._events = None
        self._name_info = None
        self._other_fields = None
        self._personal_info = None
        self._photo = None
        self._physical_addresses = None
        self._professional_info = None
        self._telephones = None

        if attachments is not None:
            self.attachments = attachments
        if billing is not None:
            self.billing = billing
        if body is not None:
            self.body = body
        if body_html is not None:
            self.body_html = body_html
        if body_rtf is not None:
            self.body_rtf = body_rtf
        if body_type is not None:
            self.body_type = body_type
        if categories is not None:
            self.categories = categories
        if companies is not None:
            self.companies = companies
        if item_id is not None:
            self.item_id = item_id
        if message_class is not None:
            self.message_class = message_class
        if mileage is not None:
            self.mileage = mileage
        if recipients is not None:
            self.recipients = recipients
        if sensitivity is not None:
            self.sensitivity = sensitivity
        if subject is not None:
            self.subject = subject
        if subject_prefix is not None:
            self.subject_prefix = subject_prefix
        if properties is not None:
            self.properties = properties
        if electronic_addresses is not None:
            self.electronic_addresses = electronic_addresses
        if events is not None:
            self.events = events
        if name_info is not None:
            self.name_info = name_info
        if other_fields is not None:
            self.other_fields = other_fields
        if personal_info is not None:
            self.personal_info = personal_info
        if photo is not None:
            self.photo = photo
        if physical_addresses is not None:
            self.physical_addresses = physical_addresses
        if professional_info is not None:
            self.professional_info = professional_info
        if telephones is not None:
            self.telephones = telephones


    @property
    def electronic_addresses(self) -> MapiContactElectronicAddressPropertySetDto:
        """
        Specify properties for up to three different e-mail addresses and three different fax addresses.             

        :return: The electronic_addresses of this MapiContactDto.
        :rtype: MapiContactElectronicAddressPropertySetDto
        """
        return self._electronic_addresses

    @electronic_addresses.setter
    def electronic_addresses(self, electronic_addresses: MapiContactElectronicAddressPropertySetDto):
        """
        Specify properties for up to three different e-mail addresses and three different fax addresses.             

        :param electronic_addresses: The electronic_addresses of this MapiContactDto.
        :type: MapiContactElectronicAddressPropertySetDto
        """
        self._electronic_addresses = electronic_addresses

    @property
    def events(self) -> MapiContactEventPropertySetDto:
        """
        Specify events associated with a contact.             

        :return: The events of this MapiContactDto.
        :rtype: MapiContactEventPropertySetDto
        """
        return self._events

    @events.setter
    def events(self, events: MapiContactEventPropertySetDto):
        """
        Specify events associated with a contact.             

        :param events: The events of this MapiContactDto.
        :type: MapiContactEventPropertySetDto
        """
        self._events = events

    @property
    def name_info(self) -> MapiContactNamePropertySetDto:
        """
        The properties are used to specify the name of the person represented by the contact.             

        :return: The name_info of this MapiContactDto.
        :rtype: MapiContactNamePropertySetDto
        """
        return self._name_info

    @name_info.setter
    def name_info(self, name_info: MapiContactNamePropertySetDto):
        """
        The properties are used to specify the name of the person represented by the contact.             

        :param name_info: The name_info of this MapiContactDto.
        :type: MapiContactNamePropertySetDto
        """
        self._name_info = name_info

    @property
    def other_fields(self) -> MapiContactOtherPropertySetDto:
        """
        Specify other fields of contact.             

        :return: The other_fields of this MapiContactDto.
        :rtype: MapiContactOtherPropertySetDto
        """
        return self._other_fields

    @other_fields.setter
    def other_fields(self, other_fields: MapiContactOtherPropertySetDto):
        """
        Specify other fields of contact.             

        :param other_fields: The other_fields of this MapiContactDto.
        :type: MapiContactOtherPropertySetDto
        """
        self._other_fields = other_fields

    @property
    def personal_info(self) -> MapiContactPersonalInfoPropertySetDto:
        """
        Specify other additional contact information.             

        :return: The personal_info of this MapiContactDto.
        :rtype: MapiContactPersonalInfoPropertySetDto
        """
        return self._personal_info

    @personal_info.setter
    def personal_info(self, personal_info: MapiContactPersonalInfoPropertySetDto):
        """
        Specify other additional contact information.             

        :param personal_info: The personal_info of this MapiContactDto.
        :type: MapiContactPersonalInfoPropertySetDto
        """
        self._personal_info = personal_info

    @property
    def photo(self) -> MapiContactPhotoDto:
        """
        Contact photo.             

        :return: The photo of this MapiContactDto.
        :rtype: MapiContactPhotoDto
        """
        return self._photo

    @photo.setter
    def photo(self, photo: MapiContactPhotoDto):
        """
        Contact photo.             

        :param photo: The photo of this MapiContactDto.
        :type: MapiContactPhotoDto
        """
        self._photo = photo

    @property
    def physical_addresses(self) -> MapiContactPhysicalAddressPropertySetDto:
        """
        Specify three physical addresses: Home Address, Work Address, and Other Address. One of the addresses can be marked as the Mailing Address.             

        :return: The physical_addresses of this MapiContactDto.
        :rtype: MapiContactPhysicalAddressPropertySetDto
        """
        return self._physical_addresses

    @physical_addresses.setter
    def physical_addresses(self, physical_addresses: MapiContactPhysicalAddressPropertySetDto):
        """
        Specify three physical addresses: Home Address, Work Address, and Other Address. One of the addresses can be marked as the Mailing Address.             

        :param physical_addresses: The physical_addresses of this MapiContactDto.
        :type: MapiContactPhysicalAddressPropertySetDto
        """
        self._physical_addresses = physical_addresses

    @property
    def professional_info(self) -> MapiContactProfessionalPropertySetDto:
        """
        Properties are used to store professional details for the person represented by the contact.             

        :return: The professional_info of this MapiContactDto.
        :rtype: MapiContactProfessionalPropertySetDto
        """
        return self._professional_info

    @professional_info.setter
    def professional_info(self, professional_info: MapiContactProfessionalPropertySetDto):
        """
        Properties are used to store professional details for the person represented by the contact.             

        :param professional_info: The professional_info of this MapiContactDto.
        :type: MapiContactProfessionalPropertySetDto
        """
        self._professional_info = professional_info

    @property
    def telephones(self) -> MapiContactTelephonePropertySetDto:
        """
        Specify telephone numbers for the contact.             

        :return: The telephones of this MapiContactDto.
        :rtype: MapiContactTelephonePropertySetDto
        """
        return self._telephones

    @telephones.setter
    def telephones(self, telephones: MapiContactTelephonePropertySetDto):
        """
        Specify telephone numbers for the contact.             

        :param telephones: The telephones of this MapiContactDto.
        :type: MapiContactTelephonePropertySetDto
        """
        self._telephones = telephones

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiContactDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import six

from AsposeEmailCloudSdk.api_client import ApiClient
from AsposeEmailCloudSdk.rest import ApiException


class ApiBase(object):
    def __init__(self, api_client: ApiClient):
        self.api_client = api_client

    @staticmethod
    def _select_header_accept(accepts):
        """Returns `Accept` based on an array of accepts provided.

        :param accepts: List of headers.
        :return: Accept (e.g. application/json).
        """
        if not accepts:
            return None

        accepts = [x.lower() for x in accepts]

        if 'application/json' in accepts:
            return 'application/json'

        return ', '.join(accepts)

    @staticmethod
    def _select_header_content_type(content_types):
        """Returns `Content-Type` based on an array of content_types provided.

        :param content_types: List of content-types.
        :return: Content-Type (e.g. application/json).
        """
        if not content_types:
            return 'application/json'

        content_types = [x.lower() for x in content_types]

        if 'application/json' in content_types or '*/*' in content_types:
            return 'application/json'

        return content_types[0]

    @staticmethod
    def _lowercase_first_letter(string):
        """
        Converts first letter of the string to lowercase

        :param string: initial string
        :return: initial string with first character in lowercase
        """
        if not string:
            return string

        return string[0].lower() + string[1:]

    def _make_request(self, http_request, method, return_type):
        def call_api():
            return self.api_client.call_api(
                resource_path=http_request.resource_path,
                method=method,
                path_params=http_request.path_params,
                query_params=http_request.query_params,
                header_params=http_request.header_params,
                body=http_request.body_params,
                post_params=http_request.form_params,
                files=http_request.files,
                response_type=return_type,
                auth_settings=http_request.auth_settings,
                _return_http_data_only=http_request.return_http_data_only,
                _preload_content=http_request.preload_content,
                _request_timeout=http_request.request_timeout,
                collection_formats=http_request.collection_formats)

        try:
            return call_api()
        except ApiException as ex:
            if ex.code == 401:
                self._request_token()
                return call_api()
            raise

    def _request_token(self):
        config = self.api_client.configuration
        request_url = "/connect/token"
        form_params = [('grant_type', 'client_credentials'), ('client_id', config.api_key['client_id']),
                       ('client_secret', config.api_key['client_secret'])]

        header_params = {'Accept': 'application/json', 'Content-Type': 'application/x-www-form-urlencoded'}

        api_version = self.api_client.configuration.api_version
        self.api_client.configuration.api_version = ''

        data = self.api_client.call_api(request_url, 'POST',
                                        {},
                                        [],
                                        header_params,
                                        post_params=form_params,
                                        response_type='object',
                                        files={}, _return_http_data_only=True,
                                        host=config.get_auth_url())
        access_token = data['access_token'] if six.PY3 else data['access_token'].encode('utf8')
        self.api_client.configuration.access_token = access_token

        self.api_client.configuration.api_version = api_version



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="client_account_api.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

from AsposeEmailCloudSdk.api.api_base import ApiBase
from AsposeEmailCloudSdk.models import *


class ClientAccountApi(ApiBase):
    """
    Aspose.Email Cloud API. ClientAccountApi operations.

    """

    def __init__(self, api_client):
        super(ClientAccountApi, self).__init__(api_client)

    def get(self, request: ClientAccountGetRequest) -> EmailClientAccount:
        """Get email client account from storage.             


        :param request: ClientAccountGetRequest object with parameters
        :type request: ClientAccountGetRequest
        :return: EmailClientAccount
        """
        # verify the required parameter 'file_name' is set
        if request.file_name is None:
            raise ValueError("Missing the required parameter `file_name` when calling `get`")

        collection_formats = {}
        path = '/email/client/account'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('fileName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.file_name if request.file_name is not None else '')
        else:
            if request.file_name is not None:
                query_params.append((self._lowercase_first_letter('fileName'), request.file_name))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'EmailClientAccount')

    def get_multi(self, request: ClientAccountGetMultiRequest) -> EmailClientMultiAccount:
        """Get email client multi account file (*.multi.account). Will respond error if file extension is not \&quot;.multi.account\&quot;.             


        :param request: ClientAccountGetMultiRequest object with parameters
        :type request: ClientAccountGetMultiRequest
        :return: EmailClientMultiAccount
        """
        # verify the required parameter 'file_name' is set
        if request.file_name is None:
            raise ValueError("Missing the required parameter `file_name` when calling `get_multi`")

        collection_formats = {}
        path = '/email/client/account/multi'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('fileName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.file_name if request.file_name is not None else '')
        else:
            if request.file_name is not None:
                query_params.append((self._lowercase_first_letter('fileName'), request.file_name))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'EmailClientMultiAccount')

    def save(self, request: ClientAccountSaveRequest):
        """Create/update email client account file (*.account) with credentials             

        :param request: Email account information
        :type request: ClientAccountSaveRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `save`")

        collection_formats = {}
        path = '/email/client/account'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)

    def save_multi(self, request: ClientAccountSaveMultiRequest):
        """Create email client multi account file (*.multi.account). Will respond error if file extension is not \&quot;.multi.account\&quot;.             

        :param request: Email accounts information.
        :type request: ClientAccountSaveMultiRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `save_multi`")

        collection_formats = {}
        path = '/email/client/account/multi'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="file_api.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

from AsposeEmailCloudSdk.api.api_base import ApiBase
from AsposeEmailCloudSdk.models import *


class FileApi(ApiBase):
    """
    Aspose.Email Cloud API. FileApi operations.

    """

    def __init__(self, api_client):
        super(FileApi, self).__init__(api_client)

    def copy_file(self, request: CopyFileRequest):
        """Copy file


        :param request: CopyFileRequest object with parameters
        :type request: CopyFileRequest
        :return: None
        """
        # verify the required parameter 'src_path' is set
        if request.src_path is None:
            raise ValueError("Missing the required parameter `src_path` when calling `copy_file`")
        # verify the required parameter 'dest_path' is set
        if request.dest_path is None:
            raise ValueError("Missing the required parameter `dest_path` when calling `copy_file`")

        collection_formats = {}
        path = '/email/storage/file/copy/{srcPath}'
        path_params = {}
        if request.src_path is not None:
            path_params[self._lowercase_first_letter('srcPath')] = request.src_path

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('destPath') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.dest_path if request.dest_path is not None else '')
        else:
            if request.dest_path is not None:
                query_params.append((self._lowercase_first_letter('destPath'), request.dest_path))
        path_parameter = '{' + self._lowercase_first_letter('srcStorageName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.src_storage_name if request.src_storage_name is not None else '')
        else:
            if request.src_storage_name is not None:
                query_params.append((self._lowercase_first_letter('srcStorageName'), request.src_storage_name))
        path_parameter = '{' + self._lowercase_first_letter('destStorageName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.dest_storage_name if request.dest_storage_name is not None else '')
        else:
            if request.dest_storage_name is not None:
                query_params.append((self._lowercase_first_letter('destStorageName'), request.dest_storage_name))
        path_parameter = '{' + self._lowercase_first_letter('versionId') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.version_id if request.version_id is not None else '')
        else:
            if request.version_id is not None:
                query_params.append((self._lowercase_first_letter('versionId'), request.version_id))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)

    def delete_file(self, request: DeleteFileRequest):
        """Delete file


        :param request: DeleteFileRequest object with parameters
        :type request: DeleteFileRequest
        :return: None
        """
        # verify the required parameter 'path' is set
        if request.path is None:
            raise ValueError("Missing the required parameter `path` when calling `delete_file`")

        collection_formats = {}
        path = '/email/storage/file/{path}'
        path_params = {}
        if request.path is not None:
            path_params[self._lowercase_first_letter('path')] = request.path

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('storageName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage_name if request.storage_name is not None else '')
        else:
            if request.storage_name is not None:
                query_params.append((self._lowercase_first_letter('storageName'), request.storage_name))
        path_parameter = '{' + self._lowercase_first_letter('versionId') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.version_id if request.version_id is not None else '')
        else:
            if request.version_id is not None:
                query_params.append((self._lowercase_first_letter('versionId'), request.version_id))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'DELETE', None)

    def download_file(self, request: DownloadFileRequest) -> str:
        """Download file


        :param request: DownloadFileRequest object with parameters
        :type request: DownloadFileRequest
        :return: str
        """
        # verify the required parameter 'path' is set
        if request.path is None:
            raise ValueError("Missing the required parameter `path` when calling `download_file`")

        collection_formats = {}
        path = '/email/storage/file/{path}'
        path_params = {}
        if request.path is not None:
            path_params[self._lowercase_first_letter('path')] = request.path

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('storageName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage_name if request.storage_name is not None else '')
        else:
            if request.storage_name is not None:
                query_params.append((self._lowercase_first_letter('storageName'), request.storage_name))
        path_parameter = '{' + self._lowercase_first_letter('versionId') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.version_id if request.version_id is not None else '')
        else:
            if request.version_id is not None:
                query_params.append((self._lowercase_first_letter('versionId'), request.version_id))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['multipart/form-data'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'file')

    def move_file(self, request: MoveFileRequest):
        """Move file


        :param request: MoveFileRequest object with parameters
        :type request: MoveFileRequest
        :return: None
        """
        # verify the required parameter 'src_path' is set
        if request.src_path is None:
            raise ValueError("Missing the required parameter `src_path` when calling `move_file`")
        # verify the required parameter 'dest_path' is set
        if request.dest_path is None:
            raise ValueError("Missing the required parameter `dest_path` when calling `move_file`")

        collection_formats = {}
        path = '/email/storage/file/move/{srcPath}'
        path_params = {}
        if request.src_path is not None:
            path_params[self._lowercase_first_letter('srcPath')] = request.src_path

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('destPath') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.dest_path if request.dest_path is not None else '')
        else:
            if request.dest_path is not None:
                query_params.append((self._lowercase_first_letter('destPath'), request.dest_path))
        path_parameter = '{' + self._lowercase_first_letter('srcStorageName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.src_storage_name if request.src_storage_name is not None else '')
        else:
            if request.src_storage_name is not None:
                query_params.append((self._lowercase_first_letter('srcStorageName'), request.src_storage_name))
        path_parameter = '{' + self._lowercase_first_letter('destStorageName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.dest_storage_name if request.dest_storage_name is not None else '')
        else:
            if request.dest_storage_name is not None:
                query_params.append((self._lowercase_first_letter('destStorageName'), request.dest_storage_name))
        path_parameter = '{' + self._lowercase_first_letter('versionId') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.version_id if request.version_id is not None else '')
        else:
            if request.version_id is not None:
                query_params.append((self._lowercase_first_letter('versionId'), request.version_id))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)

    def upload_file(self, request: UploadFileRequest) -> FilesUploadResult:
        """Upload file


        :param request: UploadFileRequest object with parameters
        :type request: UploadFileRequest
        :return: FilesUploadResult
        """
        # verify the required parameter 'path' is set
        if request.path is None:
            raise ValueError("Missing the required parameter `path` when calling `upload_file`")
        # verify the required parameter 'file' is set
        if request.file is None:
            raise ValueError("Missing the required parameter `file` when calling `upload_file`")

        collection_formats = {}
        path = '/email/storage/file/{path}'
        path_params = {}
        if request.path is not None:
            path_params[self._lowercase_first_letter('path')] = request.path

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('storageName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage_name if request.storage_name is not None else '')
        else:
            if request.storage_name is not None:
                query_params.append((self._lowercase_first_letter('storageName'), request.storage_name))

        form_params = []
        local_var_files = []
        if request.file is not None:
            local_var_files.append((self._lowercase_first_letter('File'), request.file))

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['multipart/form-data'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'FilesUploadResult')




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiContactElectronicAddressPropertySetDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.mapi_contact_electronic_address_dto import MapiContactElectronicAddressDto


class MapiContactElectronicAddressPropertySetDto(object):
    """Specify properties for up to three different e-mail addresses (Email1, Email2, and Email3) and three different fax addresses (Primary Fax, Business Fax, and Home Fax)             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'business_fax': 'MapiContactElectronicAddressDto',
        'default_email_address': 'MapiContactElectronicAddressDto',
        'email1': 'MapiContactElectronicAddressDto',
        'email2': 'MapiContactElectronicAddressDto',
        'email3': 'MapiContactElectronicAddressDto',
        'home_fax': 'MapiContactElectronicAddressDto',
        'is_empty': 'bool',
        'primary_fax': 'MapiContactElectronicAddressDto',
        'use_autocomplete': 'bool'
    }

    attribute_map = {
        'business_fax': 'businessFax',
        'default_email_address': 'defaultEmailAddress',
        'email1': 'email1',
        'email2': 'email2',
        'email3': 'email3',
        'home_fax': 'homeFax',
        'is_empty': 'isEmpty',
        'primary_fax': 'primaryFax',
        'use_autocomplete': 'useAutocomplete'
    }

    def __init__(self, business_fax: MapiContactElectronicAddressDto = None, default_email_address: MapiContactElectronicAddressDto = None, email1: MapiContactElectronicAddressDto = None, email2: MapiContactElectronicAddressDto = None, email3: MapiContactElectronicAddressDto = None, home_fax: MapiContactElectronicAddressDto = None, is_empty: bool = None, primary_fax: MapiContactElectronicAddressDto = None, use_autocomplete: bool = None):
        """
        Specify properties for up to three different e-mail addresses (Email1, Email2, and Email3) and three different fax addresses (Primary Fax, Business Fax, and Home Fax)             
        :param business_fax: Refers to the group of properties that define the business fax address for a contact.
        :type business_fax: MapiContactElectronicAddressDto
        :param default_email_address: Default value of electronic address Uses when user does not set any electronic address if UseAutocomplete property is set 'true'             
        :type default_email_address: MapiContactElectronicAddressDto
        :param email1: Refers to the group of properties that define the first e-mail address for a contact.             
        :type email1: MapiContactElectronicAddressDto
        :param email2: Refers to the group of properties that define the second e-mail address for a contact.             
        :type email2: MapiContactElectronicAddressDto
        :param email3: Refers to the group of properties that define the third e-mail address for a contact.             
        :type email3: MapiContactElectronicAddressDto
        :param home_fax: Refers to the group of properties that define the home fax address for a contact.             
        :type home_fax: MapiContactElectronicAddressDto
        :param is_empty: Shows if MapiContactElectronicAddressPropertySetDto is empty
        :type is_empty: bool
        :param primary_fax: Refers to the group of properties that define the primary fax address for a contact.             
        :type primary_fax: MapiContactElectronicAddressDto
        :param use_autocomplete: Indicates that one electronic address is completed automatically in case if user does not set any electronic address             
        :type use_autocomplete: bool
        """

        self._business_fax = None
        self._default_email_address = None
        self._email1 = None
        self._email2 = None
        self._email3 = None
        self._home_fax = None
        self._is_empty = None
        self._primary_fax = None
        self._use_autocomplete = None

        if business_fax is not None:
            self.business_fax = business_fax
        if default_email_address is not None:
            self.default_email_address = default_email_address
        if email1 is not None:
            self.email1 = email1
        if email2 is not None:
            self.email2 = email2
        if email3 is not None:
            self.email3 = email3
        if home_fax is not None:
            self.home_fax = home_fax
        if is_empty is not None:
            self.is_empty = is_empty
        if primary_fax is not None:
            self.primary_fax = primary_fax
        if use_autocomplete is not None:
            self.use_autocomplete = use_autocomplete


    @property
    def business_fax(self) -> MapiContactElectronicAddressDto:
        """
        Refers to the group of properties that define the business fax address for a contact.

        :return: The business_fax of this MapiContactElectronicAddressPropertySetDto.
        :rtype: MapiContactElectronicAddressDto
        """
        return self._business_fax

    @business_fax.setter
    def business_fax(self, business_fax: MapiContactElectronicAddressDto):
        """
        Refers to the group of properties that define the business fax address for a contact.

        :param business_fax: The business_fax of this MapiContactElectronicAddressPropertySetDto.
        :type: MapiContactElectronicAddressDto
        """
        self._business_fax = business_fax

    @property
    def default_email_address(self) -> MapiContactElectronicAddressDto:
        """
        Default value of electronic address Uses when user does not set any electronic address if UseAutocomplete property is set 'true'             

        :return: The default_email_address of this MapiContactElectronicAddressPropertySetDto.
        :rtype: MapiContactElectronicAddressDto
        """
        return self._default_email_address

    @default_email_address.setter
    def default_email_address(self, default_email_address: MapiContactElectronicAddressDto):
        """
        Default value of electronic address Uses when user does not set any electronic address if UseAutocomplete property is set 'true'             

        :param default_email_address: The default_email_address of this MapiContactElectronicAddressPropertySetDto.
        :type: MapiContactElectronicAddressDto
        """
        self._default_email_address = default_email_address

    @property
    def email1(self) -> MapiContactElectronicAddressDto:
        """
        Refers to the group of properties that define the first e-mail address for a contact.             

        :return: The email1 of this MapiContactElectronicAddressPropertySetDto.
        :rtype: MapiContactElectronicAddressDto
        """
        return self._email1

    @email1.setter
    def email1(self, email1: MapiContactElectronicAddressDto):
        """
        Refers to the group of properties that define the first e-mail address for a contact.             

        :param email1: The email1 of this MapiContactElectronicAddressPropertySetDto.
        :type: MapiContactElectronicAddressDto
        """
        self._email1 = email1

    @property
    def email2(self) -> MapiContactElectronicAddressDto:
        """
        Refers to the group of properties that define the second e-mail address for a contact.             

        :return: The email2 of this MapiContactElectronicAddressPropertySetDto.
        :rtype: MapiContactElectronicAddressDto
        """
        return self._email2

    @email2.setter
    def email2(self, email2: MapiContactElectronicAddressDto):
        """
        Refers to the group of properties that define the second e-mail address for a contact.             

        :param email2: The email2 of this MapiContactElectronicAddressPropertySetDto.
        :type: MapiContactElectronicAddressDto
        """
        self._email2 = email2

    @property
    def email3(self) -> MapiContactElectronicAddressDto:
        """
        Refers to the group of properties that define the third e-mail address for a contact.             

        :return: The email3 of this MapiContactElectronicAddressPropertySetDto.
        :rtype: MapiContactElectronicAddressDto
        """
        return self._email3

    @email3.setter
    def email3(self, email3: MapiContactElectronicAddressDto):
        """
        Refers to the group of properties that define the third e-mail address for a contact.             

        :param email3: The email3 of this MapiContactElectronicAddressPropertySetDto.
        :type: MapiContactElectronicAddressDto
        """
        self._email3 = email3

    @property
    def home_fax(self) -> MapiContactElectronicAddressDto:
        """
        Refers to the group of properties that define the home fax address for a contact.             

        :return: The home_fax of this MapiContactElectronicAddressPropertySetDto.
        :rtype: MapiContactElectronicAddressDto
        """
        return self._home_fax

    @home_fax.setter
    def home_fax(self, home_fax: MapiContactElectronicAddressDto):
        """
        Refers to the group of properties that define the home fax address for a contact.             

        :param home_fax: The home_fax of this MapiContactElectronicAddressPropertySetDto.
        :type: MapiContactElectronicAddressDto
        """
        self._home_fax = home_fax

    @property
    def is_empty(self) -> bool:
        """
        Shows if MapiContactElectronicAddressPropertySetDto is empty

        :return: The is_empty of this MapiContactElectronicAddressPropertySetDto.
        :rtype: bool
        """
        return self._is_empty

    @is_empty.setter
    def is_empty(self, is_empty: bool):
        """
        Shows if MapiContactElectronicAddressPropertySetDto is empty

        :param is_empty: The is_empty of this MapiContactElectronicAddressPropertySetDto.
        :type: bool
        """
        if is_empty is None:
            raise ValueError("Invalid value for `is_empty`, must not be `None`")
        self._is_empty = is_empty

    @property
    def primary_fax(self) -> MapiContactElectronicAddressDto:
        """
        Refers to the group of properties that define the primary fax address for a contact.             

        :return: The primary_fax of this MapiContactElectronicAddressPropertySetDto.
        :rtype: MapiContactElectronicAddressDto
        """
        return self._primary_fax

    @primary_fax.setter
    def primary_fax(self, primary_fax: MapiContactElectronicAddressDto):
        """
        Refers to the group of properties that define the primary fax address for a contact.             

        :param primary_fax: The primary_fax of this MapiContactElectronicAddressPropertySetDto.
        :type: MapiContactElectronicAddressDto
        """
        self._primary_fax = primary_fax

    @property
    def use_autocomplete(self) -> bool:
        """
        Indicates that one electronic address is completed automatically in case if user does not set any electronic address             

        :return: The use_autocomplete of this MapiContactElectronicAddressPropertySetDto.
        :rtype: bool
        """
        return self._use_autocomplete

    @use_autocomplete.setter
    def use_autocomplete(self, use_autocomplete: bool):
        """
        Indicates that one electronic address is completed automatically in case if user does not set any electronic address             

        :param use_autocomplete: The use_autocomplete of this MapiContactElectronicAddressPropertySetDto.
        :type: bool
        """
        if use_autocomplete is None:
            raise ValueError("Invalid value for `use_autocomplete`, must not be `None`")
        self._use_autocomplete = use_autocomplete

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiContactElectronicAddressPropertySetDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="EmailDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.alternate_view import AlternateView
from AsposeEmailCloudSdk.models.attachment import Attachment
from AsposeEmailCloudSdk.models.linked_resource import LinkedResource
from AsposeEmailCloudSdk.models.mail_address import MailAddress


class EmailDto(object):
    """Email message representation.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alternate_views': 'list[AlternateView]',
        'attachments': 'list[Attachment]',
        'bcc': 'list[MailAddress]',
        'body': 'str',
        'body_encoding': 'str',
        'body_type': 'str',
        'cc': 'list[MailAddress]',
        '_date': 'datetime',
        'delivery_notification_options': 'list[str]',
        '_from': 'MailAddress',
        'headers': 'dict(str, str)',
        'html_body': 'str',
        'html_body_text': 'str',
        'is_body_html': 'bool',
        'is_draft': 'bool',
        'is_encrypted': 'bool',
        'is_signed': 'bool',
        'linked_resources': 'list[LinkedResource]',
        'message_id': 'str',
        'original_is_tnef': 'bool',
        'preferred_text_encoding': 'str',
        'priority': 'str',
        'read_receipt_to': 'list[MailAddress]',
        'reply_to_list': 'list[MailAddress]',
        'reverse_path': 'MailAddress',
        'sender': 'MailAddress',
        'sensitivity': 'str',
        'subject': 'str',
        'subject_encoding': 'str',
        'time_zone_offset': 'int',
        'to': 'list[MailAddress]',
        'x_mailer': 'str'
    }

    attribute_map = {
        'alternate_views': 'alternateViews',
        'attachments': 'attachments',
        'bcc': 'bcc',
        'body': 'body',
        'body_encoding': 'bodyEncoding',
        'body_type': 'bodyType',
        'cc': 'cc',
        '_date': 'date',
        'delivery_notification_options': 'deliveryNotificationOptions',
        '_from': 'from',
        'headers': 'headers',
        'html_body': 'htmlBody',
        'html_body_text': 'htmlBodyText',
        'is_body_html': 'isBodyHtml',
        'is_draft': 'isDraft',
        'is_encrypted': 'isEncrypted',
        'is_signed': 'isSigned',
        'linked_resources': 'linkedResources',
        'message_id': 'messageId',
        'original_is_tnef': 'originalIsTnef',
        'preferred_text_encoding': 'preferredTextEncoding',
        'priority': 'priority',
        'read_receipt_to': 'readReceiptTo',
        'reply_to_list': 'replyToList',
        'reverse_path': 'reversePath',
        'sender': 'sender',
        'sensitivity': 'sensitivity',
        'subject': 'subject',
        'subject_encoding': 'subjectEncoding',
        'time_zone_offset': 'timeZoneOffset',
        'to': 'to',
        'x_mailer': 'xMailer'
    }

    def __init__(self, alternate_views: List[AlternateView] = None, attachments: List[Attachment] = None, bcc: List[MailAddress] = None, body: str = None, body_encoding: str = None, body_type: str = None, cc: List[MailAddress] = None, _date: datetime = None, delivery_notification_options: List[str] = None, _from: MailAddress = None, headers: Dict[str, str] = None, html_body: str = None, html_body_text: str = None, is_body_html: bool = None, is_draft: bool = None, is_encrypted: bool = None, is_signed: bool = None, linked_resources: List[LinkedResource] = None, message_id: str = None, original_is_tnef: bool = None, preferred_text_encoding: str = None, priority: str = None, read_receipt_to: List[MailAddress] = None, reply_to_list: List[MailAddress] = None, reverse_path: MailAddress = None, sender: MailAddress = None, sensitivity: str = None, subject: str = None, subject_encoding: str = None, time_zone_offset: int = None, to: List[MailAddress] = None, x_mailer: str = None):
        """
        Email message representation.             
        :param alternate_views: Collection of alternate views of message.             
        :type alternate_views: List[AlternateView]
        :param attachments: Email message attachments.             
        :type attachments: List[Attachment]
        :param bcc: BCC recipients.             
        :type bcc: List[MailAddress]
        :param body: Email message body as plain text.             
        :type body: str
        :param body_encoding: Body encoding.             
        :type body_encoding: str
        :param body_type: The content type of message body. Enum, available values: PlainText, Html, Rtf
        :type body_type: str
        :param cc: CC recipients.             
        :type cc: List[MailAddress]
        :param _date: Message date.             
        :type _date: datetime
        :param delivery_notification_options: Delivery notifications.
        :type delivery_notification_options: List[str]
        :param _from: From address.             
        :type _from: MailAddress
        :param headers: Document headers.             
        :type headers: Dict[str, str]
        :param html_body: HTML body.             
        :type html_body: str
        :param html_body_text: Html body as plain text. Read only.             
        :type html_body_text: str
        :param is_body_html: Indicates whether the message body is in Html.             
        :type is_body_html: bool
        :param is_draft: Indicates whether or not a message has been sent.             
        :type is_draft: bool
        :param is_encrypted: Indicates whether the message is encrypted. Read only.             
        :type is_encrypted: bool
        :param is_signed: Indicates whether the message is signed. Read only.             
        :type is_signed: bool
        :param linked_resources: Linked resources of message.             
        :type linked_resources: List[LinkedResource]
        :param message_id: Message id.             
        :type message_id: str
        :param original_is_tnef: Indicates whether original EML message is in TNEF format. Read only.             
        :type original_is_tnef: bool
        :param preferred_text_encoding: Preferred encoding.             
        :type preferred_text_encoding: str
        :param priority: Email priority status. Enum, available values: High, Low, Normal
        :type priority: str
        :param read_receipt_to: Read receipt addresses.             
        :type read_receipt_to: List[MailAddress]
        :param reply_to_list: The list of addresses to reply to for the mail message.             
        :type reply_to_list: List[MailAddress]
        :param reverse_path: ReversePath address.             
        :type reverse_path: MailAddress
        :param sender: Sender address.             
        :type sender: MailAddress
        :param sensitivity: Specifies the sensitivity of a MailMessage. Enum, available values: None, Normal, Personal, Private, CompanyConfidential
        :type sensitivity: str
        :param subject: Message subject.             
        :type subject: str
        :param subject_encoding: Subject encoding.             
        :type subject_encoding: str
        :param time_zone_offset: Coordinated Universal Time (UTC) offset for the message dates. This property defines the time zone difference, between the local time and UTC represented as count of ticks (10 000 per millisecond).             
        :type time_zone_offset: int
        :param to: The address collection that contains the recipients of message.             
        :type to: List[MailAddress]
        :param x_mailer: The X-Mailer the software that created the e-mail message.             
        :type x_mailer: str
        """

        self._alternate_views = None
        self._attachments = None
        self._bcc = None
        self._body = None
        self._body_encoding = None
        self._body_type = None
        self._cc = None
        self.__date = None
        self._delivery_notification_options = None
        self.__from = None
        self._headers = None
        self._html_body = None
        self._html_body_text = None
        self._is_body_html = None
        self._is_draft = None
        self._is_encrypted = None
        self._is_signed = None
        self._linked_resources = None
        self._message_id = None
        self._original_is_tnef = None
        self._preferred_text_encoding = None
        self._priority = None
        self._read_receipt_to = None
        self._reply_to_list = None
        self._reverse_path = None
        self._sender = None
        self._sensitivity = None
        self._subject = None
        self._subject_encoding = None
        self._time_zone_offset = None
        self._to = None
        self._x_mailer = None

        if alternate_views is not None:
            self.alternate_views = alternate_views
        if attachments is not None:
            self.attachments = attachments
        if bcc is not None:
            self.bcc = bcc
        if body is not None:
            self.body = body
        if body_encoding is not None:
            self.body_encoding = body_encoding
        if body_type is not None:
            self.body_type = body_type
        if cc is not None:
            self.cc = cc
        if _date is not None:
            self._date = _date
        if delivery_notification_options is not None:
            self.delivery_notification_options = delivery_notification_options
        if _from is not None:
            self._from = _from
        if headers is not None:
            self.headers = headers
        if html_body is not None:
            self.html_body = html_body
        if html_body_text is not None:
            self.html_body_text = html_body_text
        if is_body_html is not None:
            self.is_body_html = is_body_html
        if is_draft is not None:
            self.is_draft = is_draft
        if is_encrypted is not None:
            self.is_encrypted = is_encrypted
        if is_signed is not None:
            self.is_signed = is_signed
        if linked_resources is not None:
            self.linked_resources = linked_resources
        if message_id is not None:
            self.message_id = message_id
        if original_is_tnef is not None:
            self.original_is_tnef = original_is_tnef
        if preferred_text_encoding is not None:
            self.preferred_text_encoding = preferred_text_encoding
        if priority is not None:
            self.priority = priority
        if read_receipt_to is not None:
            self.read_receipt_to = read_receipt_to
        if reply_to_list is not None:
            self.reply_to_list = reply_to_list
        if reverse_path is not None:
            self.reverse_path = reverse_path
        if sender is not None:
            self.sender = sender
        if sensitivity is not None:
            self.sensitivity = sensitivity
        if subject is not None:
            self.subject = subject
        if subject_encoding is not None:
            self.subject_encoding = subject_encoding
        if time_zone_offset is not None:
            self.time_zone_offset = time_zone_offset
        if to is not None:
            self.to = to
        if x_mailer is not None:
            self.x_mailer = x_mailer


    @property
    def alternate_views(self) -> List[AlternateView]:
        """
        Collection of alternate views of message.             

        :return: The alternate_views of this EmailDto.
        :rtype: list[AlternateView]
        """
        return self._alternate_views

    @alternate_views.setter
    def alternate_views(self, alternate_views: List[AlternateView]):
        """
        Collection of alternate views of message.             

        :param alternate_views: The alternate_views of this EmailDto.
        :type: list[AlternateView]
        """
        self._alternate_views = alternate_views

    @property
    def attachments(self) -> List[Attachment]:
        """
        Email message attachments.             

        :return: The attachments of this EmailDto.
        :rtype: list[Attachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments: List[Attachment]):
        """
        Email message attachments.             

        :param attachments: The attachments of this EmailDto.
        :type: list[Attachment]
        """
        self._attachments = attachments

    @property
    def bcc(self) -> List[MailAddress]:
        """
        BCC recipients.             

        :return: The bcc of this EmailDto.
        :rtype: list[MailAddress]
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc: List[MailAddress]):
        """
        BCC recipients.             

        :param bcc: The bcc of this EmailDto.
        :type: list[MailAddress]
        """
        self._bcc = bcc

    @property
    def body(self) -> str:
        """
        Email message body as plain text.             

        :return: The body of this EmailDto.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body: str):
        """
        Email message body as plain text.             

        :param body: The body of this EmailDto.
        :type: str
        """
        self._body = body

    @property
    def body_encoding(self) -> str:
        """
        Body encoding.             

        :return: The body_encoding of this EmailDto.
        :rtype: str
        """
        return self._body_encoding

    @body_encoding.setter
    def body_encoding(self, body_encoding: str):
        """
        Body encoding.             

        :param body_encoding: The body_encoding of this EmailDto.
        :type: str
        """
        self._body_encoding = body_encoding

    @property
    def body_type(self) -> str:
        """
        The content type of message body. Enum, available values: PlainText, Html, Rtf

        :return: The body_type of this EmailDto.
        :rtype: str
        """
        return self._body_type

    @body_type.setter
    def body_type(self, body_type: str):
        """
        The content type of message body. Enum, available values: PlainText, Html, Rtf

        :param body_type: The body_type of this EmailDto.
        :type: str
        """
        if body_type is None:
            raise ValueError("Invalid value for `body_type`, must not be `None`")
        self._body_type = body_type

    @property
    def cc(self) -> List[MailAddress]:
        """
        CC recipients.             

        :return: The cc of this EmailDto.
        :rtype: list[MailAddress]
        """
        return self._cc

    @cc.setter
    def cc(self, cc: List[MailAddress]):
        """
        CC recipients.             

        :param cc: The cc of this EmailDto.
        :type: list[MailAddress]
        """
        self._cc = cc

    @property
    def _date(self) -> datetime:
        """
        Message date.             

        :return: The _date of this EmailDto.
        :rtype: datetime
        """
        return self.__date

    @_date.setter
    def _date(self, _date: datetime):
        """
        Message date.             

        :param _date: The _date of this EmailDto.
        :type: datetime
        """
        if _date is None:
            raise ValueError("Invalid value for `_date`, must not be `None`")
        self.__date = _date

    @property
    def delivery_notification_options(self) -> List[str]:
        """
        Delivery notifications. Items: Email delivery notification options. Enum, available values: Delay, Never, None, OnFailure, OnSuccess

        :return: The delivery_notification_options of this EmailDto.
        :rtype: list[str]
        """
        return self._delivery_notification_options

    @delivery_notification_options.setter
    def delivery_notification_options(self, delivery_notification_options: List[str]):
        """
        Delivery notifications. Items: Email delivery notification options. Enum, available values: Delay, Never, None, OnFailure, OnSuccess

        :param delivery_notification_options: The delivery_notification_options of this EmailDto.
        :type: list[str]
        """
        self._delivery_notification_options = delivery_notification_options

    @property
    def _from(self) -> MailAddress:
        """
        From address.             

        :return: The _from of this EmailDto.
        :rtype: MailAddress
        """
        return self.__from

    @_from.setter
    def _from(self, _from: MailAddress):
        """
        From address.             

        :param _from: The _from of this EmailDto.
        :type: MailAddress
        """
        self.__from = _from

    @property
    def headers(self) -> Dict[str, str]:
        """
        Document headers.             

        :return: The headers of this EmailDto.
        :rtype: dict(str, str)
        """
        return self._headers

    @headers.setter
    def headers(self, headers: Dict[str, str]):
        """
        Document headers.             

        :param headers: The headers of this EmailDto.
        :type: dict(str, str)
        """
        self._headers = headers

    @property
    def html_body(self) -> str:
        """
        HTML body.             

        :return: The html_body of this EmailDto.
        :rtype: str
        """
        return self._html_body

    @html_body.setter
    def html_body(self, html_body: str):
        """
        HTML body.             

        :param html_body: The html_body of this EmailDto.
        :type: str
        """
        self._html_body = html_body

    @property
    def html_body_text(self) -> str:
        """
        Html body as plain text. Read only.             

        :return: The html_body_text of this EmailDto.
        :rtype: str
        """
        return self._html_body_text

    @html_body_text.setter
    def html_body_text(self, html_body_text: str):
        """
        Html body as plain text. Read only.             

        :param html_body_text: The html_body_text of this EmailDto.
        :type: str
        """
        self._html_body_text = html_body_text

    @property
    def is_body_html(self) -> bool:
        """
        Indicates whether the message body is in Html.             

        :return: The is_body_html of this EmailDto.
        :rtype: bool
        """
        return self._is_body_html

    @is_body_html.setter
    def is_body_html(self, is_body_html: bool):
        """
        Indicates whether the message body is in Html.             

        :param is_body_html: The is_body_html of this EmailDto.
        :type: bool
        """
        if is_body_html is None:
            raise ValueError("Invalid value for `is_body_html`, must not be `None`")
        self._is_body_html = is_body_html

    @property
    def is_draft(self) -> bool:
        """
        Indicates whether or not a message has been sent.             

        :return: The is_draft of this EmailDto.
        :rtype: bool
        """
        return self._is_draft

    @is_draft.setter
    def is_draft(self, is_draft: bool):
        """
        Indicates whether or not a message has been sent.             

        :param is_draft: The is_draft of this EmailDto.
        :type: bool
        """
        if is_draft is None:
            raise ValueError("Invalid value for `is_draft`, must not be `None`")
        self._is_draft = is_draft

    @property
    def is_encrypted(self) -> bool:
        """
        Indicates whether the message is encrypted. Read only.             

        :return: The is_encrypted of this EmailDto.
        :rtype: bool
        """
        return self._is_encrypted

    @is_encrypted.setter
    def is_encrypted(self, is_encrypted: bool):
        """
        Indicates whether the message is encrypted. Read only.             

        :param is_encrypted: The is_encrypted of this EmailDto.
        :type: bool
        """
        if is_encrypted is None:
            raise ValueError("Invalid value for `is_encrypted`, must not be `None`")
        self._is_encrypted = is_encrypted

    @property
    def is_signed(self) -> bool:
        """
        Indicates whether the message is signed. Read only.             

        :return: The is_signed of this EmailDto.
        :rtype: bool
        """
        return self._is_signed

    @is_signed.setter
    def is_signed(self, is_signed: bool):
        """
        Indicates whether the message is signed. Read only.             

        :param is_signed: The is_signed of this EmailDto.
        :type: bool
        """
        if is_signed is None:
            raise ValueError("Invalid value for `is_signed`, must not be `None`")
        self._is_signed = is_signed

    @property
    def linked_resources(self) -> List[LinkedResource]:
        """
        Linked resources of message.             

        :return: The linked_resources of this EmailDto.
        :rtype: list[LinkedResource]
        """
        return self._linked_resources

    @linked_resources.setter
    def linked_resources(self, linked_resources: List[LinkedResource]):
        """
        Linked resources of message.             

        :param linked_resources: The linked_resources of this EmailDto.
        :type: list[LinkedResource]
        """
        self._linked_resources = linked_resources

    @property
    def message_id(self) -> str:
        """
        Message id.             

        :return: The message_id of this EmailDto.
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id: str):
        """
        Message id.             

        :param message_id: The message_id of this EmailDto.
        :type: str
        """
        self._message_id = message_id

    @property
    def original_is_tnef(self) -> bool:
        """
        Indicates whether original EML message is in TNEF format. Read only.             

        :return: The original_is_tnef of this EmailDto.
        :rtype: bool
        """
        return self._original_is_tnef

    @original_is_tnef.setter
    def original_is_tnef(self, original_is_tnef: bool):
        """
        Indicates whether original EML message is in TNEF format. Read only.             

        :param original_is_tnef: The original_is_tnef of this EmailDto.
        :type: bool
        """
        if original_is_tnef is None:
            raise ValueError("Invalid value for `original_is_tnef`, must not be `None`")
        self._original_is_tnef = original_is_tnef

    @property
    def preferred_text_encoding(self) -> str:
        """
        Preferred encoding.             

        :return: The preferred_text_encoding of this EmailDto.
        :rtype: str
        """
        return self._preferred_text_encoding

    @preferred_text_encoding.setter
    def preferred_text_encoding(self, preferred_text_encoding: str):
        """
        Preferred encoding.             

        :param preferred_text_encoding: The preferred_text_encoding of this EmailDto.
        :type: str
        """
        self._preferred_text_encoding = preferred_text_encoding

    @property
    def priority(self) -> str:
        """
        Email priority status. Enum, available values: High, Low, Normal

        :return: The priority of this EmailDto.
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority: str):
        """
        Email priority status. Enum, available values: High, Low, Normal

        :param priority: The priority of this EmailDto.
        :type: str
        """
        if priority is None:
            raise ValueError("Invalid value for `priority`, must not be `None`")
        self._priority = priority

    @property
    def read_receipt_to(self) -> List[MailAddress]:
        """
        Read receipt addresses.             

        :return: The read_receipt_to of this EmailDto.
        :rtype: list[MailAddress]
        """
        return self._read_receipt_to

    @read_receipt_to.setter
    def read_receipt_to(self, read_receipt_to: List[MailAddress]):
        """
        Read receipt addresses.             

        :param read_receipt_to: The read_receipt_to of this EmailDto.
        :type: list[MailAddress]
        """
        self._read_receipt_to = read_receipt_to

    @property
    def reply_to_list(self) -> List[MailAddress]:
        """
        The list of addresses to reply to for the mail message.             

        :return: The reply_to_list of this EmailDto.
        :rtype: list[MailAddress]
        """
        return self._reply_to_list

    @reply_to_list.setter
    def reply_to_list(self, reply_to_list: List[MailAddress]):
        """
        The list of addresses to reply to for the mail message.             

        :param reply_to_list: The reply_to_list of this EmailDto.
        :type: list[MailAddress]
        """
        self._reply_to_list = reply_to_list

    @property
    def reverse_path(self) -> MailAddress:
        """
        ReversePath address.             

        :return: The reverse_path of this EmailDto.
        :rtype: MailAddress
        """
        return self._reverse_path

    @reverse_path.setter
    def reverse_path(self, reverse_path: MailAddress):
        """
        ReversePath address.             

        :param reverse_path: The reverse_path of this EmailDto.
        :type: MailAddress
        """
        self._reverse_path = reverse_path

    @property
    def sender(self) -> MailAddress:
        """
        Sender address.             

        :return: The sender of this EmailDto.
        :rtype: MailAddress
        """
        return self._sender

    @sender.setter
    def sender(self, sender: MailAddress):
        """
        Sender address.             

        :param sender: The sender of this EmailDto.
        :type: MailAddress
        """
        self._sender = sender

    @property
    def sensitivity(self) -> str:
        """
        Specifies the sensitivity of a MailMessage. Enum, available values: None, Normal, Personal, Private, CompanyConfidential

        :return: The sensitivity of this EmailDto.
        :rtype: str
        """
        return self._sensitivity

    @sensitivity.setter
    def sensitivity(self, sensitivity: str):
        """
        Specifies the sensitivity of a MailMessage. Enum, available values: None, Normal, Personal, Private, CompanyConfidential

        :param sensitivity: The sensitivity of this EmailDto.
        :type: str
        """
        if sensitivity is None:
            raise ValueError("Invalid value for `sensitivity`, must not be `None`")
        self._sensitivity = sensitivity

    @property
    def subject(self) -> str:
        """
        Message subject.             

        :return: The subject of this EmailDto.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject: str):
        """
        Message subject.             

        :param subject: The subject of this EmailDto.
        :type: str
        """
        self._subject = subject

    @property
    def subject_encoding(self) -> str:
        """
        Subject encoding.             

        :return: The subject_encoding of this EmailDto.
        :rtype: str
        """
        return self._subject_encoding

    @subject_encoding.setter
    def subject_encoding(self, subject_encoding: str):
        """
        Subject encoding.             

        :param subject_encoding: The subject_encoding of this EmailDto.
        :type: str
        """
        self._subject_encoding = subject_encoding

    @property
    def time_zone_offset(self) -> int:
        """
        Coordinated Universal Time (UTC) offset for the message dates. This property defines the time zone difference, between the local time and UTC represented as count of ticks (10 000 per millisecond).             

        :return: The time_zone_offset of this EmailDto.
        :rtype: int
        """
        return self._time_zone_offset

    @time_zone_offset.setter
    def time_zone_offset(self, time_zone_offset: int):
        """
        Coordinated Universal Time (UTC) offset for the message dates. This property defines the time zone difference, between the local time and UTC represented as count of ticks (10 000 per millisecond).             

        :param time_zone_offset: The time_zone_offset of this EmailDto.
        :type: int
        """
        self._time_zone_offset = time_zone_offset

    @property
    def to(self) -> List[MailAddress]:
        """
        The address collection that contains the recipients of message.             

        :return: The to of this EmailDto.
        :rtype: list[MailAddress]
        """
        return self._to

    @to.setter
    def to(self, to: List[MailAddress]):
        """
        The address collection that contains the recipients of message.             

        :param to: The to of this EmailDto.
        :type: list[MailAddress]
        """
        self._to = to

    @property
    def x_mailer(self) -> str:
        """
        The X-Mailer the software that created the e-mail message.             

        :return: The x_mailer of this EmailDto.
        :rtype: str
        """
        return self._x_mailer

    @x_mailer.setter
    def x_mailer(self, x_mailer: str):
        """
        The X-Mailer the software that created the e-mail message.             

        :param x_mailer: The x_mailer of this EmailDto.
        :type: str
        """
        self._x_mailer = x_mailer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="client_group.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import
from AsposeEmailCloudSdk.api import *


class ClientGroup(object):
    """
    Builtin Email client operations.
    """
    def __init__(self, api_client):
        self._account = ClientAccountApi(api_client)
        self._folder = ClientFolderApi(api_client)
        self._message = ClientMessageApi(api_client)
        self._thread = ClientThreadApi(api_client)

    @property
    def account(self) -> ClientAccountApi:
        """
        Email server account for built-in client operations.
        """
        return self._account

    @property
    def folder(self) -> ClientFolderApi:
        """
        Email client folder operations.
        """
        return self._folder

    @property
    def message(self) -> ClientMessageApi:
        """
        Email client message operations.
        """
        return self._message

    @property
    def thread(self) -> ClientThreadApi:
        """
        Email client thread operations.
        """
        return self._thread



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="ai_bcr_parse_request.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from AsposeEmailCloudSdk.models import *


class AiBcrParseRequest(object):
    """
    Request model for ai_bcr_parse operation.
    Initializes a new instance.

    :param file: File to parse
    :type file: str
    :param countries: Comma-separated codes of countries.
    :type countries: str
    :param languages: Comma-separated ISO-639 codes of languages (either 639-1 or 639-3; i.e. \"it\" or \"ita\" for Italian); it's \"\" by default.             
    :type languages: str
    :param is_single: Determines that image contains single VCard or more.
    :type is_single: bool
    """

    def __init__(self, file: str, countries: str = None, languages: str = None, is_single: bool = None):
        """
        Request model for ai_bcr_parse operation.
        Initializes a new instance.

        :param file: File to parse
        :type file: str
        :param countries: Comma-separated codes of countries.
        :type countries: str
        :param languages: Comma-separated ISO-639 codes of languages (either 639-1 or 639-3; i.e. \"it\" or \"ita\" for Italian); it's \"\" by default.             
        :type languages: str
        :param is_single: Determines that image contains single VCard or more.
        :type is_single: bool
        """

        self.file = file
        self.countries = countries
        self.languages = languages
        self.is_single = is_single




# coding: utf-8

"""
    Aspose.Email Cloud is a REST API for creating email applications that work with common email file formats. It lets developers manipulate message formats such as Outlook MSG, EML and MHT files.
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "aspose-email-cloud"
VERSION = "21.4.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "..", 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name=NAME,
    version=VERSION,
    url='https://products.aspose.cloud/email/family',
    classifiers = [
        'License :: OSI Approved :: MIT License',
    ],
    license = "License :: OSI Approved :: MIT License",
    description="Aspose.Email Cloud API",
    author_email="",
    keywords=["Swagger", "Aspose.Email Cloud API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type='text/markdown',
)



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="EmailAccountConfig.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.name_value_pair import NameValuePair


class EmailAccountConfig(object):
    """Email account configuration.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'protocol_type': 'str',
        'host': 'str',
        'port': 'int',
        'socket_type': 'str',
        'authentication_types': 'list[str]',
        'extra_info': 'list[NameValuePair]',
        'is_validated': 'bool'
    }

    attribute_map = {
        'display_name': 'displayName',
        'protocol_type': 'protocolType',
        'host': 'host',
        'port': 'port',
        'socket_type': 'socketType',
        'authentication_types': 'authenticationTypes',
        'extra_info': 'extraInfo',
        'is_validated': 'isValidated'
    }

    def __init__(self, display_name: str = None, protocol_type: str = None, host: str = None, port: int = None, socket_type: str = None, authentication_types: List[str] = None, extra_info: List[NameValuePair] = None, is_validated: bool = None):
        """
        Email account configuration.             
        :param display_name: Email account display name             
        :type display_name: str
        :param protocol_type: Type of connection protocol. Enum, available values: IMAP, POP3, SMTP, EWS, WebDav
        :type protocol_type: str
        :param host: Email account host.             
        :type host: str
        :param port: Port.             
        :type port: int
        :param socket_type: Email account security mode Enum, available values: None, SSLExplicit, SSLImplicit, SSLAuto, Auto
        :type socket_type: str
        :param authentication_types: Supported authentication types.             
        :type authentication_types: List[str]
        :param extra_info: Extra account information.             
        :type extra_info: List[NameValuePair]
        :param is_validated: Determines that configuration validated. Set to false if validation skipped.             
        :type is_validated: bool
        """

        self._display_name = None
        self._protocol_type = None
        self._host = None
        self._port = None
        self._socket_type = None
        self._authentication_types = None
        self._extra_info = None
        self._is_validated = None

        if display_name is not None:
            self.display_name = display_name
        if protocol_type is not None:
            self.protocol_type = protocol_type
        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if socket_type is not None:
            self.socket_type = socket_type
        if authentication_types is not None:
            self.authentication_types = authentication_types
        if extra_info is not None:
            self.extra_info = extra_info
        if is_validated is not None:
            self.is_validated = is_validated


    @property
    def display_name(self) -> str:
        """
        Email account display name             

        :return: The display_name of this EmailAccountConfig.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: str):
        """
        Email account display name             

        :param display_name: The display_name of this EmailAccountConfig.
        :type: str
        """
        self._display_name = display_name

    @property
    def protocol_type(self) -> str:
        """
        Type of connection protocol. Enum, available values: IMAP, POP3, SMTP, EWS, WebDav

        :return: The protocol_type of this EmailAccountConfig.
        :rtype: str
        """
        return self._protocol_type

    @protocol_type.setter
    def protocol_type(self, protocol_type: str):
        """
        Type of connection protocol. Enum, available values: IMAP, POP3, SMTP, EWS, WebDav

        :param protocol_type: The protocol_type of this EmailAccountConfig.
        :type: str
        """
        if protocol_type is None:
            raise ValueError("Invalid value for `protocol_type`, must not be `None`")
        self._protocol_type = protocol_type

    @property
    def host(self) -> str:
        """
        Email account host.             

        :return: The host of this EmailAccountConfig.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host: str):
        """
        Email account host.             

        :param host: The host of this EmailAccountConfig.
        :type: str
        """
        self._host = host

    @property
    def port(self) -> int:
        """
        Port.             

        :return: The port of this EmailAccountConfig.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port: int):
        """
        Port.             

        :param port: The port of this EmailAccountConfig.
        :type: int
        """
        self._port = port

    @property
    def socket_type(self) -> str:
        """
        Email account security mode Enum, available values: None, SSLExplicit, SSLImplicit, SSLAuto, Auto

        :return: The socket_type of this EmailAccountConfig.
        :rtype: str
        """
        return self._socket_type

    @socket_type.setter
    def socket_type(self, socket_type: str):
        """
        Email account security mode Enum, available values: None, SSLExplicit, SSLImplicit, SSLAuto, Auto

        :param socket_type: The socket_type of this EmailAccountConfig.
        :type: str
        """
        if socket_type is None:
            raise ValueError("Invalid value for `socket_type`, must not be `None`")
        self._socket_type = socket_type

    @property
    def authentication_types(self) -> List[str]:
        """
        Supported authentication types.              Items: Email account authentication types. Enum, available values: NoAuth, OAuth2, PasswordCleartext, PasswordEncrypted, SmtpAfterPop, ClientIpAddress

        :return: The authentication_types of this EmailAccountConfig.
        :rtype: list[str]
        """
        return self._authentication_types

    @authentication_types.setter
    def authentication_types(self, authentication_types: List[str]):
        """
        Supported authentication types.              Items: Email account authentication types. Enum, available values: NoAuth, OAuth2, PasswordCleartext, PasswordEncrypted, SmtpAfterPop, ClientIpAddress

        :param authentication_types: The authentication_types of this EmailAccountConfig.
        :type: list[str]
        """
        self._authentication_types = authentication_types

    @property
    def extra_info(self) -> List[NameValuePair]:
        """
        Extra account information.             

        :return: The extra_info of this EmailAccountConfig.
        :rtype: list[NameValuePair]
        """
        return self._extra_info

    @extra_info.setter
    def extra_info(self, extra_info: List[NameValuePair]):
        """
        Extra account information.             

        :param extra_info: The extra_info of this EmailAccountConfig.
        :type: list[NameValuePair]
        """
        self._extra_info = extra_info

    @property
    def is_validated(self) -> bool:
        """
        Determines that configuration validated. Set to false if validation skipped.             

        :return: The is_validated of this EmailAccountConfig.
        :rtype: bool
        """
        return self._is_validated

    @is_validated.setter
    def is_validated(self, is_validated: bool):
        """
        Determines that configuration validated. Set to false if validation skipped.             

        :param is_validated: The is_validated of this EmailAccountConfig.
        :type: bool
        """
        if is_validated is None:
            raise ValueError("Invalid value for `is_validated`, must not be `None`")
        self._is_validated = is_validated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailAccountConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="EmailConfigDiscoverOauthRequest.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.discover_email_config_request import DiscoverEmailConfigRequest


class EmailConfigDiscoverOauthRequest(DiscoverEmailConfigRequest):
    """
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'fast_processing': 'bool',
        'login': 'str',
        'client_id': 'str',
        'client_secret': 'str',
        'refresh_token': 'str',
        'request_url': 'str'
    }

    attribute_map = {
        'address': 'address',
        'fast_processing': 'fastProcessing',
        'login': 'login',
        'client_id': 'clientId',
        'client_secret': 'clientSecret',
        'refresh_token': 'refreshToken',
        'request_url': 'requestUrl'
    }

    def __init__(self, address: str = None, fast_processing: bool = None, login: str = None, client_id: str = None, client_secret: str = None, refresh_token: str = None, request_url: str = None):
        """
        
        :param address: Email address to discover.             
        :type address: str
        :param fast_processing: Turns on fast processing. All discover systems will run in parallel. First discovered result will be returned.             
        :type fast_processing: bool
        :param login: Email account login. If not specified, address used as a login.             
        :type login: str
        :param client_id: OAuth client id.             
        :type client_id: str
        :param client_secret: OAuth client secret.             
        :type client_secret: str
        :param refresh_token: OAuth refresh token.             
        :type refresh_token: str
        :param request_url: The url to obtain access token. If not specified, will be discovered from email configuration.             
        :type request_url: str
        """
        super(EmailConfigDiscoverOauthRequest, self).__init__()

        self._client_id = None
        self._client_secret = None
        self._refresh_token = None
        self._request_url = None

        if address is not None:
            self.address = address
        if fast_processing is not None:
            self.fast_processing = fast_processing
        if login is not None:
            self.login = login
        if client_id is not None:
            self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if refresh_token is not None:
            self.refresh_token = refresh_token
        if request_url is not None:
            self.request_url = request_url


    @property
    def client_id(self) -> str:
        """
        OAuth client id.             

        :return: The client_id of this EmailConfigDiscoverOauthRequest.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id: str):
        """
        OAuth client id.             

        :param client_id: The client_id of this EmailConfigDiscoverOauthRequest.
        :type: str
        """
        if client_id is None:
            raise ValueError("Invalid value for `client_id`, must not be `None`")
        if client_id is not None and len(client_id) < 1:
            raise ValueError("Invalid value for `client_id`, length must be greater than or equal to `1`")
        self._client_id = client_id

    @property
    def client_secret(self) -> str:
        """
        OAuth client secret.             

        :return: The client_secret of this EmailConfigDiscoverOauthRequest.
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret: str):
        """
        OAuth client secret.             

        :param client_secret: The client_secret of this EmailConfigDiscoverOauthRequest.
        :type: str
        """
        if client_secret is None:
            raise ValueError("Invalid value for `client_secret`, must not be `None`")
        if client_secret is not None and len(client_secret) < 1:
            raise ValueError("Invalid value for `client_secret`, length must be greater than or equal to `1`")
        self._client_secret = client_secret

    @property
    def refresh_token(self) -> str:
        """
        OAuth refresh token.             

        :return: The refresh_token of this EmailConfigDiscoverOauthRequest.
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token: str):
        """
        OAuth refresh token.             

        :param refresh_token: The refresh_token of this EmailConfigDiscoverOauthRequest.
        :type: str
        """
        if refresh_token is None:
            raise ValueError("Invalid value for `refresh_token`, must not be `None`")
        if refresh_token is not None and len(refresh_token) < 1:
            raise ValueError("Invalid value for `refresh_token`, length must be greater than or equal to `1`")
        self._refresh_token = refresh_token

    @property
    def request_url(self) -> str:
        """
        The url to obtain access token. If not specified, will be discovered from email configuration.             

        :return: The request_url of this EmailConfigDiscoverOauthRequest.
        :rtype: str
        """
        return self._request_url

    @request_url.setter
    def request_url(self, request_url: str):
        """
        The url to obtain access token. If not specified, will be discovered from email configuration.             

        :param request_url: The request_url of this EmailConfigDiscoverOauthRequest.
        :type: str
        """
        self._request_url = request_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailConfigDiscoverOauthRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="calendar_api.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

from AsposeEmailCloudSdk.api.api_base import ApiBase
from AsposeEmailCloudSdk.models import *


class CalendarApi(ApiBase):
    """
    Aspose.Email Cloud API. CalendarApi operations.

    """

    def __init__(self, api_client):
        super(CalendarApi, self).__init__(api_client)

    def as_alternate(self, request: CalendarAsAlternateRequest) -> AlternateView:
        """Convert iCalendar to AlternateView             

        :param request: iCalendar to AlternateView request
        :type request: CalendarAsAlternateRequest
        :return: AlternateView
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `as_alternate`")

        collection_formats = {}
        path = '/email/Calendar/as-alternate'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'AlternateView')

    def as_file(self, request: CalendarAsFileRequest) -> str:
        """Converts calendar model to specified format and returns as file.             

        :param request: Calendar model and format to convert.
        :type request: CalendarAsFileRequest
        :return: str
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `as_file`")

        collection_formats = {}
        path = '/email/Calendar/as-file'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['multipart/form-data'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'file')

    def as_mapi(self, calendar_dto: CalendarDto) -> MapiCalendarDto:
        """Converts CalendarDto to MapiCalendarDto.             

        :param calendar_dto: iCalendar model calendar representation.
        :type calendar_dto: CalendarDto
        :return: MapiCalendarDto
        """
        # verify the required parameter 'calendar_dto' is set
        if calendar_dto is None:
            raise ValueError("Missing the required parameter `calendar_dto` when calling `as_mapi`")

        collection_formats = {}
        path = '/email/Calendar/as-mapi'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = calendar_dto
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'MapiCalendarDto')

    def convert(self, request: CalendarConvertRequest) -> str:
        """Converts calendar document to specified format and returns as file.             


        :param request: CalendarConvertRequest object with parameters
        :type request: CalendarConvertRequest
        :return: str
        """
        # verify the required parameter 'format' is set
        if request.format is None:
            raise ValueError("Missing the required parameter `format` when calling `convert`")
        # verify the required parameter 'file' is set
        if request.file is None:
            raise ValueError("Missing the required parameter `file` when calling `convert`")

        collection_formats = {}
        path = '/email/Calendar/convert'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('format') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.format if request.format is not None else '')
        else:
            if request.format is not None:
                query_params.append((self._lowercase_first_letter('format'), request.format))

        form_params = []
        local_var_files = []
        if request.file is not None:
            local_var_files.append((self._lowercase_first_letter('File'), request.file))

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['multipart/form-data'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['multipart/form-data'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'file')

    def from_file(self, request: CalendarFromFileRequest) -> CalendarDto:
        """Converts calendar document to a model representation.             


        :param request: CalendarFromFileRequest object with parameters
        :type request: CalendarFromFileRequest
        :return: CalendarDto
        """
        # verify the required parameter 'file' is set
        if request.file is None:
            raise ValueError("Missing the required parameter `file` when calling `from_file`")

        collection_formats = {}
        path = '/email/Calendar/from-file'
        path_params = {}

        query_params = []

        form_params = []
        local_var_files = []
        if request.file is not None:
            local_var_files.append((self._lowercase_first_letter('File'), request.file))

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['multipart/form-data'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'CalendarDto')

    def get(self, request: CalendarGetRequest) -> CalendarDto:
        """Get calendar file from storage.             


        :param request: CalendarGetRequest object with parameters
        :type request: CalendarGetRequest
        :return: CalendarDto
        """
        # verify the required parameter 'file_name' is set
        if request.file_name is None:
            raise ValueError("Missing the required parameter `file_name` when calling `get`")

        collection_formats = {}
        path = '/email/Calendar'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('fileName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.file_name if request.file_name is not None else '')
        else:
            if request.file_name is not None:
                query_params.append((self._lowercase_first_letter('fileName'), request.file_name))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'CalendarDto')

    def get_as_alternate(self, request: CalendarGetAsAlternateRequest) -> AlternateView:
        """Get iCalendar from storage as AlternateView             


        :param request: CalendarGetAsAlternateRequest object with parameters
        :type request: CalendarGetAsAlternateRequest
        :return: AlternateView
        """
        # verify the required parameter 'file_name' is set
        if request.file_name is None:
            raise ValueError("Missing the required parameter `file_name` when calling `get_as_alternate`")
        # verify the required parameter 'calendar_action' is set
        if request.calendar_action is None:
            raise ValueError("Missing the required parameter `calendar_action` when calling `get_as_alternate`")

        collection_formats = {}
        path = '/email/Calendar/as-alternate'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('fileName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.file_name if request.file_name is not None else '')
        else:
            if request.file_name is not None:
                query_params.append((self._lowercase_first_letter('fileName'), request.file_name))
        path_parameter = '{' + self._lowercase_first_letter('calendarAction') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.calendar_action if request.calendar_action is not None else '')
        else:
            if request.calendar_action is not None:
                query_params.append((self._lowercase_first_letter('calendarAction'), request.calendar_action))
        path_parameter = '{' + self._lowercase_first_letter('sequenceId') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.sequence_id if request.sequence_id is not None else '')
        else:
            if request.sequence_id is not None:
                query_params.append((self._lowercase_first_letter('sequenceId'), request.sequence_id))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'AlternateView')

    def get_as_file(self, request: CalendarGetAsFileRequest) -> str:
        """Converts calendar document from storage to specified format and returns as file.             


        :param request: CalendarGetAsFileRequest object with parameters
        :type request: CalendarGetAsFileRequest
        :return: str
        """
        # verify the required parameter 'file_name' is set
        if request.file_name is None:
            raise ValueError("Missing the required parameter `file_name` when calling `get_as_file`")
        # verify the required parameter 'format' is set
        if request.format is None:
            raise ValueError("Missing the required parameter `format` when calling `get_as_file`")

        collection_formats = {}
        path = '/email/Calendar/as-file'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('fileName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.file_name if request.file_name is not None else '')
        else:
            if request.file_name is not None:
                query_params.append((self._lowercase_first_letter('fileName'), request.file_name))
        path_parameter = '{' + self._lowercase_first_letter('format') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.format if request.format is not None else '')
        else:
            if request.format is not None:
                query_params.append((self._lowercase_first_letter('format'), request.format))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['multipart/form-data'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'file')

    def get_list(self, request: CalendarGetListRequest) -> CalendarStorageList:
        """Get iCalendar list from storage folder.             


        :param request: CalendarGetListRequest object with parameters
        :type request: CalendarGetListRequest
        :return: CalendarStorageList
        """
        # verify the required parameter 'folder' is set
        if request.folder is None:
            raise ValueError("Missing the required parameter `folder` when calling `get_list`")

        collection_formats = {}
        path = '/email/Calendar/list'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('itemsPerPage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.items_per_page if request.items_per_page is not None else '')
        else:
            if request.items_per_page is not None:
                query_params.append((self._lowercase_first_letter('itemsPerPage'), request.items_per_page))
        path_parameter = '{' + self._lowercase_first_letter('pageNumber') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.page_number if request.page_number is not None else '')
        else:
            if request.page_number is not None:
                query_params.append((self._lowercase_first_letter('pageNumber'), request.page_number))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'CalendarStorageList')

    def save(self, request: CalendarSaveRequest):
        """Save iCalendar             

        :param request: iCalendar create/update request
        :type request: CalendarSaveRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `save`")

        collection_formats = {}
        path = '/email/Calendar'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)

